==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/sr/users.php <==
<?php
regGS("That user name already exists, please choose a different login name.", "Корисничко име већ постоји, смислите нешто друго.");
regGS("User may delete article attachments", "Корисник може да брише атачменте уз чланке.");
regGS("User may change article attachments", "Корисник може да мења атачменте уз чланке");
regGS("User may add article attachments", "Корисник може да додаје атачменте уз чланке");
regGS("Staff management", "Управљање сарадничким налозима");
regGS("Subscriber management", "Управљање претплатничким налозима");
regGS("Account Name", "Име налога");
regGS("Full Name", "Пуно име");
regGS("Delete user $1", "Обриши корисника $1");
regGS("User list is empty.", "Листа корисника је празна.");
regGS("You do not have the right to create user accounts.", "Немате право да креирате корисничке налоге");
regGS("Title", "Звање");
regGS("Gender", "Пол");
regGS("Mr.", "господин");
regGS("Mrs.", "госпођа");
regGS("Ms.", "госпођица");
regGS("Dr.", "доктор");
regGS("Male", "мушки");
regGS("Female", "женски");
regGS("under 18", "испод 18");
regGS("Age", "Старост");
regGS("Confirm password", "Потврди лозинку");
regGS("E-Mail", "Е-пошта");
regGS("City", "Град");
regGS("Street Address", "Улична адреса");
regGS("Postal Code", "Поштански број");
regGS("State", "Држава");
regGS("Phone", "Телефон");
regGS("Fax", "Факс");
regGS("Contact Person", "Особа за контакт");
regGS("Second Phone", "Алтернативни телефон");
regGS("Employer", "Послодавац");
regGS("Employer Type", "Врста послодавца");
regGS("Corporate", "Комерцијална делатност");
regGS("Non-Governmental Organisation", "Невладина организација");
regGS("Government Agency", "Владина агенција");
regGS("Academic", "Академска установа");
regGS("Media", "Медијска кућа");
regGS("Position", "Позиција");
regGS("Show more user details", "Прикажи додатне податке о кориснику");
regGS("Hide user details", "Сакриј податке о кориснику");
regGS("You must select a $1", "Морате изабрати $1");
regGS("The password must be at least 6 characters long and both passwords should match.", "Лозинка мора бити дугачка најмање 6 карактера и обе лозинке се морају поклапати");
regGS("The user account could not be created.", "Кориснички налог не може бити креиран");
regGS("User account $1 was created successfully.", "Кориснички налог $1 је успешно направљен.");
regGS("Click here to change password", "Кликните овде за промену лозинке");
regGS("Old Password", "Стара лозинка");
regGS("You do not have the right to change user account permissions.", "Немате право да мењате додељена права за корисничке налоге");
regGS("Permissions for $1 changed", "Додељена права за $1 су измењена");
regGS("You do not have the right to change user account information.", "Немате право да мењате податке за кориснички налог ");
regGS("Click here to customize user permissions", "Кликните овде за измену права корисника");
regGS("Click here to use existing user type permissions (discard customization)", "Кликните овде за коришћење постојећих права за тип корисника (поништава измене)");
regGS("Click here to leave password unchanged", "Кликните овде да оставите лозинку неизмењену");
regGS("User account information changed for $1", "Подаци за кориснички налог $1 су промењени");
regGS("The password you typed is incorrect.", "Лозинка коју сте унели је неисправна");
regGS("You do not have the right to delete user accounts.", "Немате право да бришете корисничке налоге");
regGS("Are you sure you want to delete the user account $1 ?", "Да ли сте сигурни да желите да обришете кориснички налог $1?");
regGS("User account $1 was deleted successfully.", "Кориснички налог $1 је успешно обрисан.");
regGS("User IP access list management", "Управљање листом приступа преко корисничких IP адреса");
regGS("No records.", "Без података");
regGS("Start IP", "Почетна IP адреса");
regGS("Number of addresses", "Број адреса");
regGS("The IP Group $1 has been created.", "Група заснована на IP адреси је креирана");
regGS("There was an error creating the IP address group.", "Дошло је до грешке при креирању групе засноване на ИП адреси.");
regGS("Are you sure you want to delete the IP Group $1?", "Сигурни сте да желите да обришете IP групу $1?");
regGS("The IP address group $1 has been deleted.", "Група заснована на IP адреси $1 је обрисана");
regGS("User '$1' information was changed successfully.", "Подаци о кориснику '$1' су успешно промењени.");
regGS("IP address", "ИП адреса");
regGS("fill in from left to right at least one input box", "попуните са лева на десно најмање једно поље");
regGS("User Type", "Тип корисника");
regGS("You must input a valid EMail address.", "Морате унети исправну е-маил адресу.");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "Лозинка мора бити дугачка најмање 6 знакова и мора се поклапати са потврдом.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "Морате унети број између о и 255 у поље $1 код почетне ИП адресе");
regGS("Delete subscriptions to $1", "Обриши претплате за $1");
regGS("Change user account information", "Промените податке за кориснички налог");
regGS("The IP address group $1:$2 conflicts with another existing group.", "ИП адресна група $1:$2 се сукобљава са другом, већ постојећом групом.");
regGS("Creation Date", "Датум креирања");
regGS("User Name", "Корисничко име");
regGS("User management", "Администрација корисницима");
regGS("Set", "Постави");
regGS("Update", "Измени");
regGS("Rights", "Права");
regGS("IP Access", "IP приступ");
regGS("Staff", "Особље");
regGS("Adding new user account", "Додавање новог корисничког налога");
regGS("You must select an user type.", "Морате изабрати тип корисника");
regGS("The user account $1 has been created.", "Креиран је кориснички налог за $1 ");
regGS("Please check if an account with the same user name does not already exist.", "Проверите да ли налог под тим корисничким именом већ не постоји");
regGS("Change password", "Промени лозинку");
regGS("You do not have the right to change user passwords.", "Немате право да мењате корисничке лозинке");
regGS("Changing user password", "Мењање корисничке лозинке");
regGS("The password could not be changed.", "Лозинка не може бити промењена");
regGS("The password has been changed.", "Лозинка је промењена");
regGS("User may manage templates", "Корисник може да управља шаблонима");
regGS("User may add/change country entries", "Корисник може да додаје/мења податке о државама");
regGS("Edit user account permissions", "Прикажи додељена права за кориснички налог");
regGS("This user account does not have permissions information.", "Овај кориснички налог нема информација о додељеним правима");
regGS("Updating user account permissions", "Измена додељених права за кориснички налог");
regGS("User account permissions have been successfuly updated.", "Додељена права за кориснички налог успешно су измењена");
regGS("User account permissions could not be updated.", "Додељена права за кориснички налог не могу бити измењена");
regGS("Changing user account information", "Мењање података за кориснички налог");
regGS("User account information has been changed.", "Подаци за кориснички налог су промењени");
regGS("User account information could not be changed.", "Подаци за кориснички налог не могу бити промењени");
regGS("Old password", "Стара лозинка");
regGS("New password", "Нова лозинка");
regGS("Confirm new password", "Потврди нову лозинку");
regGS("Changing your password", "Мењање ваше лозинке");
regGS("User $1 changed his password", "Корисник $1 је променио лозинку");
regGS("Delete user account", "Обриши кориснички налог");
regGS("Deleting user account", "Брисање корисничког налога");
regGS("The user account $1 could not be deleted.", "Кориснички налог $1 не може бити обрисан");
regGS("No such user.", "Нема таквог корисника");
regGS("Delete IP Group $1", "Обриши IP групу $1");
regGS("IP Access List", "Листа приступа на основу IP адреса");
regGS("Adding new IP Group", "Додавање нове групе засноване на IP адреси");
regGS("The IP Group could not be created.", "IP група не може бити креирана");
regGS("Please check if an account with the same IP Group does not already exist.", "Проверите да ли налог са истом IP групом већ не постоји");
regGS("Delete IP Group", "Обриши IP групу");
regGS("You do not have the right to delete IP Groups.", "Немате право да бришете IP групе");
regGS("No such IP Group.", "Нема такве IP групе");
regGS("Deleting IP Group", "Брисање IP групе");
regGS("The IP Group could not be deleted.", "IP група не може бити обрисана");
regGS("No IP Group.", "Нема ИП групе.");
?>

==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sr/users.php <==
<?php
regGS("65 or over", "65 или више");
regGS("User may translate articles", "Корисник може да преводи текстове");
regGS("User may move articles", "Корисник може да премешта текстове");
regGS("User may find and replace", "Корисник може да користи опцију 'тражи/замени'");
regGS("User may change system preferences", "Корисник може да мења системске поставке");
regGS("User may attach topics to articles", "Корисник може да додаје теме текстовима");
regGS("User may attach images to articles", "Корисник може да качи слике уз текстове");
regGS("User may add special characters", "Корисник може да додаје специјалне знакове");
regGS("Reset search form", "Поништи услове претраге");
regGS("That user name already exists, please choose a different login name.", "Корисничко име већ постоји, смислите нешто друго.");
regGS("User may delete article attachments", "Корисник може да брише атачменте уз чланке.");
regGS("User may change article attachments", "Корисник може да мења атачменте уз чланке");
regGS("User may add article attachments", "Корисник може да додаје атачменте уз чланке");
regGS("Staff management", "Управљање сарадничким налозима");
regGS("Subscriber management", "Управљање претплатничким налозима");
regGS("Account Name", "Корисничко име");
regGS("Full Name", "Пуно име");
regGS("Delete user $1", "Обриши корисника $1");
regGS("User list is empty.", "Листа корисника је празна.");
regGS("You do not have the right to create user accounts.", "Немате право да креирате корисничке налоге");
regGS("Title", "Звање");
regGS("Gender", "Пол");
regGS("Mr.", "господин");
regGS("Mrs.", "госпођа");
regGS("Ms.", "госпођица");
regGS("Dr.", "доктор");
regGS("Male", "мушки");
regGS("Female", "женски");
regGS("under 18", "испод 18");
regGS("Age", "Старост");
regGS("Confirm password", "Потврди лозинку");
regGS("E-Mail", "Е-пошта");
regGS("City", "Град");
regGS("Street Address", "Улична адреса");
regGS("Postal Code", "Поштански број");
regGS("State", "Држава");
regGS("Phone", "Телефон");
regGS("Fax", "Факс");
regGS("Contact Person", "Особа за контакт");
regGS("Second Phone", "Алтернативни телефон");
regGS("Employer", "Послодавац");
regGS("Employer Type", "Врста послодавца");
regGS("Corporate", "Комерцијална делатност");
regGS("Non-Governmental Organisation", "Невладина организација");
regGS("Government Agency", "Владина агенција");
regGS("Academic", "Академска установа");
regGS("Media", "Медијска кућа");
regGS("Position", "Позиција");
regGS("Show more user details", "Прикажи додатне податке о кориснику");
regGS("Hide user details", "Сакриј податке о кориснику");
regGS("You must select a $1", "Морате изабрати $1");
regGS("The password must be at least 6 characters long and both passwords should match.", "Лозинка мора бити дугачка најмање 6 карактера и обе лозинке се морају поклапати");
regGS("The user account could not be created.", "Кориснички налог не може бити креиран");
regGS("User account $1 was created successfully.", "Кориснички налог $1 је успешно направљен.");
regGS("Click here to change password", "Кликните овде за промену лозинке");
regGS("Old Password", "Стара лозинка");
regGS("You do not have the right to change user account permissions.", "Немате право да мењате додељена права за корисничке налоге");
regGS("Permissions for $1 changed", "Додељена права за $1 су измењена");
regGS("You do not have the right to change user account information.", "Немате право да мењате податке за кориснички налог ");
regGS("Click here to customize user permissions", "Кликните овде за измену права корисника");
regGS("Click here to use existing user type permissions (discard customization)", "Кликните овде за коришћење постојећих права за тип корисника (поништава измене)");
regGS("Click here to leave password unchanged", "Кликните овде да оставите лозинку неизмењену");
regGS("User account information changed for $1", "Подаци за кориснички налог $1 су промењени");
regGS("The password you typed is incorrect.", "Лозинка коју сте унели је неисправна");
regGS("You do not have the right to delete user accounts.", "Немате право да бришете корисничке налоге");
regGS("Are you sure you want to delete the user account $1 ?", "Да ли сте сигурни да желите да обришете кориснички налог $1?");
regGS("User account $1 was deleted successfully.", "Кориснички налог $1 је успешно обрисан.");
regGS("User IP access list management", "Управљање листом приступа преко корисничких IP адреса");
regGS("No records.", "Без података");
regGS("Start IP", "Почетна IP адреса");
regGS("Number of addresses", "Број адреса");
regGS("The IP Group $1 has been created.", "Група заснована на IP адреси је креирана");
regGS("There was an error creating the IP address group.", "Дошло је до грешке при креирању групе засноване на ИП адреси.");
regGS("Are you sure you want to delete the IP Group $1?", "Сигурни сте да желите да обришете IP групу $1?");
regGS("The IP address group $1 has been deleted.", "Група заснована на IP адреси $1 је обрисана");
regGS("User '$1' information was changed successfully.", "Подаци о кориснику '$1' су успешно промењени.");
regGS("IP address", "ИП адреса");
regGS("fill in from left to right at least one input box", "попуните са лева на десно најмање једно поље");
regGS("User Type", "Тип корисника");
regGS("You must input a valid EMail address.", "Морате унети исправну е-маил адресу.");
regGS("The confirm password must be at least 6 characters long and both passwords should match.", "Лозинка мора бити дугачка најмање 6 знакова и мора се поклапати са потврдом.");
regGS("You must input a number between 0 and 255 into the Start IP address' $1 field.", "Морате унети број између о и 255 у поље $1 код почетне ИП адресе");
regGS("Delete subscriptions to $1", "Обриши претплате за $1");
regGS("Change user account information", "Промените податке за кориснички налог");
regGS("The IP address group $1:$2 conflicts with another existing group.", "ИП адресна група $1:$2 се сукобљава са другом, већ постојећом групом.");
regGS("Creation Date", "Датум креирања");
regGS("User Name", "Корисничко име");
regGS("User management", "Администрација корисницима");
regGS("Set", "Постави");
regGS("Update", "Измени");
regGS("Rights", "Права");
regGS("IP Access", "IP приступ");
regGS("Staff", "Особље");
regGS("Adding new user account", "Додавање новог корисничког налога");
regGS("You must select an user type.", "Морате изабрати тип корисника");
regGS("The user account $1 has been created.", "Креиран је кориснички налог за $1 ");
regGS("Please check if an account with the same user name does not already exist.", "Проверите да ли налог под тим корисничким именом већ не постоји");
regGS("Change password", "Промени лозинку");
regGS("You do not have the right to change user passwords.", "Немате право да мењате корисничке лозинке");
regGS("Changing user password", "Мењање корисничке лозинке");
regGS("The password could not be changed.", "Лозинка не може бити промењена");
regGS("The password has been changed.", "Лозинка је промењена");
regGS("User may manage templates", "Корисник може да управља шаблонима");
regGS("User may add/change country entries", "Корисник може да додаје/мења податке о државама");
regGS("Edit user account permissions", "Прикажи додељена права за кориснички налог");
regGS("This user account does not have permissions information.", "Овај кориснички налог нема информација о додељеним правима");
regGS("Updating user account permissions", "Измена додељених права за кориснички налог");
regGS("User account permissions have been successfuly updated.", "Додељена права за кориснички налог успешно су измењена");
regGS("User account permissions could not be updated.", "Додељена права за кориснички налог не могу бити измењена");
regGS("Changing user account information", "Мењање података за кориснички налог");
regGS("User account information has been changed.", "Подаци за кориснички налог су промењени");
regGS("User account information could not be changed.", "Подаци за кориснички налог не могу бити промењени");
regGS("Old password", "Стара лозинка");
regGS("New password", "Нова лозинка");
regGS("Confirm new password", "Потврди нову лозинку");
regGS("Changing your password", "Мењање ваше лозинке");
regGS("User $1 changed his password", "Корисник $1 је променио лозинку");
regGS("Delete user account", "Обриши кориснички налог");
regGS("Deleting user account", "Брисање корисничког налога");
regGS("The user account $1 could not be deleted.", "Кориснички налог $1 не може бити обрисан");
regGS("No such user.", "Нема таквог корисника");
regGS("Delete IP Group $1", "Обриши IP групу $1");
regGS("IP Access List", "Листа приступа на основу IP адреса");
regGS("Adding new IP Group", "Додавање нове групе засноване на IP адреси");
regGS("The IP Group could not be created.", "IP група не може бити креирана");
regGS("Please check if an account with the same IP Group does not already exist.", "Проверите да ли налог са истом IP групом већ не постоји");
regGS("Delete IP Group", "Обриши IP групу");
regGS("You do not have the right to delete IP Groups.", "Немате право да бришете IP групе");
regGS("No such IP Group.", "Нема такве IP групе");
regGS("Deleting IP Group", "Брисање IP групе");
regGS("The IP Group could not be deleted.", "IP група не може бити обрисана");
regGS("No IP Group.", "Нема ИП групе.");
?>
